@@ -47,6 +47,11 @@
 #endif
 #endif
 
+#ifndef CLOBBER_TOS_WORKAROUND_START
+#define CLOBBER_TOS_WORKAROUND_START
+#define CLOBBER_TOS_WORKAROUND_END
+#endif
+
 #ifndef INDIRECT_THREADED
 #ifndef DIRECT_THREADED
 #define DIRECT_THREADED
